module.exports = defineTest({
	description: 'properly remove unused function and class expressions'
});
